==> fluent-0.6.0.tar.gz: fluent/src/Plugin/FluentFieldResolver/CommonField.php <==
<?php

namespace Drupal\fluent\Plugin\FluentFieldResolver;

use Drupal\Core\Field\FieldDefinitionInterface;
use Drupal\Core\Field\FieldItemListInterface;
use Drupal\fluent\Plugin\FluentFieldResolverBase;

/**
 * @FluentFieldResolver(
 *   id = "common_field",
 *   label = "Commond Field Resolver",
 *   weight = 100
 * )
 */
class CommonField extends FluentFieldResolverBase {

  /**
   *
   */
  public function handler($object, $fieldName, array $options = []) {
    if ($object instanceof FieldItemListInterface) {
      $position = $options['position'];

      if ($position === -1) {
        return $object->getValue();
      }

      return $object->first();
    }

    if ($method = $this->getMethod($object, $fieldName)) {
      return $object->{$method}();
    }

    try {
      $field = $object->get($fieldName);
    } catch (\InvalidArgumentException $e) {
      // TODO: Error handling.
      $fields = array_keys($object->getFields());
      $message = sprintf(
        'Available fields: %s

      Available methods: %s',
        implode(', ', $fields),
        implode(', ', get_class_methods($object))
      );

      throw new \Exception($message);
    }

    return $field;
  }

  /**
   * @param FieldDefinitionInterface $fieldDefinition
   * @return bool
   */
  public function can(FieldDefinitionInterface $fieldDefinition): bool {
    return TRUE;
  }

  public function hasField($object, $fieldName) {
    return method_exists($object, 'hasField') && $object->hasField($fieldName);
  }

  public function getMethod($object, $possibleName) {
    if ($this->isMethod($object, $possibleName)) {
      return $possibleName;
    }

    $tmpName = 'get' . ucfirst($possibleName);
    if ($this->isMethod($object, $tmpName)) {
      return $tmpName;
    }

    $tmpName = 'is' . ucfirst($possibleName);
    if ($this->isMethod($object, $tmpName)) {
      return $tmpName;
    }
  }

  /**
   * @param $entity
   * @param $name
   *
   * @return bool
   */
  public function isMethod($entity, $name) {
    return method_exists($entity, $name);
  }

}

==> fluent-0.7.0.tar.gz: fluent/src/Plugin/FluentFieldResolver/CommonField.php <==
<?php

namespace Drupal\fluent\Plugin\FluentFieldResolver;

use Drupal\Core\Field\FieldDefinitionInterface;
use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\TypedData\PrimitiveBase;
use Drupal\fluent\Exception\NotFieldFoundException;
use Drupal\fluent\FieldControl;
use Drupal\fluent\Plugin\FluentFieldResolverBase;

/**
 * @FluentFieldResolver(
 *   id = "common_field",
 *   label = "Commond Field Resolver",
 *   weight = 100
 * )
 */
class CommonField extends FluentFieldResolverBase {

  /**
   *
   */
  public function handler($object, $fieldName, FieldControl $fieldControl) {
    if ($object instanceof FieldItemListInterface) {
      // @todo: field cardinality check.
      return $object->first();
    }

    if ($method = $this->getMethod($object, $fieldName)) {
      return $object->{$method}();
    }

    // @todo:
    if ($object instanceof PrimitiveBase) {
      return $object->getValue();
    }

    try {
      $field = $object->get($fieldName);
    }
    catch (\InvalidArgumentException $e) {
      // @todo Error handling.
      $fields = array_keys($object->getFields());
      $message = sprintf(
            'Available fields: %s

      Available methods: %s',
            implode(', ', $fields),
            implode(', ', get_class_methods($object))
            );

      throw new NotFieldFoundException($message);
    }

    return $field;
  }

  /**
   * @param  \Drupal\Core\Field\FieldDefinitionInterface $fieldDefinition
   * @return bool
   */
  public function can(FieldDefinitionInterface $fieldDefinition): bool {
    return TRUE;
  }

  /**
   *
   */
  public function hasField($object, $fieldName) {
    return method_exists($object, 'hasField') && $object->hasField($fieldName);
  }

  /**
   *
   */
  public function getMethod($object, $possibleName) {
    if ($this->isMethod($object, $possibleName)) {
      return $possibleName;
    }

    $tmpName = 'get' . ucfirst($possibleName);
    if ($this->isMethod($object, $tmpName)) {
      return $tmpName;
    }

    $tmpName = 'is' . ucfirst($possibleName);
    if ($this->isMethod($object, $tmpName)) {
      return $tmpName;
    }
  }

  /**
   * @param $entity
   * @param $name
   *
   * @return bool
   */
  public function isMethod($entity, $name) {
    return method_exists($entity, $name);
  }

}
